/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.fusiontables.model;

import com.google.api.client.json.GenericJson;

/**
 * Specifies the minimum and maximum values, the color, opacity, icon and weight of a bucket within
 * a StyleSetting.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Fusion Tables API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Bucket extends GenericJson {

  /**
   * Color of line or the interior of a polygon in #RRGGBB format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String color;

  /**
   * Icon name used for a point.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String icon;

  /**
   * Maximum value in the selected column for a row to be styled according to the bucket color,
   * opacity, icon, or weight.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double max;

  /**
   * Minimum value in the selected column for a row to be styled according to the bucket color,
   * opacity, icon, or weight.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double min;

  /**
   * Opacity of the color: 0.0 (transparent) to 1.0 (opaque).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double opacity;

  /**
   * Width of a line (in pixels).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer weight;

  /**
   * Color of line or the interior of a polygon in #RRGGBB format.
   * The value returned may be {@code null}.
   */
  public String getColor() {
    return color;
  }

  /**
   * Color of line or the interior of a polygon in #RRGGBB format.
   * The value set may be {@code null}.
   */
  public Bucket setColor(String color) {
    this.color = color;
    return this;
  }

  /**
   * Icon name used for a point.
   * The value returned may be {@code null}.
   */
  public String getIcon() {
    return icon;
  }

  /**
   * Icon name used for a point.
   * The value set may be {@code null}.
   */
  public Bucket setIcon(String icon) {
    this.icon = icon;
    return this;
  }

  /**
   * Maximum value in the selected column for a row to be styled according to the bucket color,
   * opacity, icon, or weight.
   * The value returned may be {@code null}.
   */
  public Double getMax() {
    return max;
  }

  /**
   * Maximum value in the selected column for a row to be styled according to the bucket color,
   * opacity, icon, or weight.
   * The value set may be {@code null}.
   */
  public Bucket setMax(Double max) {
    this.max = max;
    return this;
  }

  /**
   * Minimum value in the selected column for a row to be styled according to the bucket color,
   * opacity, icon, or weight.
   * The value returned may be {@code null}.
   */
  public Double getMin() {
    return min;
  }

  /**
   * Minimum value in the selected column for a row to be styled according to the bucket color,
   * opacity, icon, or weight.
   * The value set may be {@code null}.
   */
  public Bucket setMin(Double min) {
    this.min = min;
    return this;
  }

  /**
   * Opacity of the color: 0.0 (transparent) to 1.0 (opaque).
   * The value returned may be {@code null}.
   */
  public Double getOpacity() {
    return opacity;
  }

  /**
   * Opacity of the color: 0.0 (transparent) to 1.0 (opaque).
   * The value set may be {@code null}.
   */
  public Bucket setOpacity(Double opacity) {
    this.opacity = opacity;
    return this;
  }

  /**
   * Width of a line (in pixels).
   * The value returned may be {@code null}.
   */
  public Integer getWeight() {
    return weight;
  }

  /**
   * Width of a line (in pixels).
   * The value set may be {@code null}.
   */
  public Bucket setWeight(Integer weight) {
    this.weight = weight;
    return this;
  }

}
