/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.fusiontables.model;

import com.google.api.client.json.GenericJson;

/**
 * Specifies the id, name and type of a column in a table.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Fusion Tables API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Column extends GenericJson {

  /**
   * Optional identifier of the base column. If present, this column is derived from the specified
   * base column.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private BaseColumn baseColumn;

  /**
   * Identifier for the column.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer columnId;

  /**
   * Type name: a template for an individual column.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Required name of the column.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * Required type of the column.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String type;

  /**
   * Optional identifier of the base column. If present, this column is derived from the specified
   * base column.
   * The value returned may be {@code null}.
   */
  public BaseColumn getBaseColumn() {
    return baseColumn;
  }

  /**
   * Optional identifier of the base column. If present, this column is derived from the specified
   * base column.
   * The value set may be {@code null}.
   */
  public Column setBaseColumn(BaseColumn baseColumn) {
    this.baseColumn = baseColumn;
    return this;
  }

  /**
   * Identifier for the column.
   * The value returned may be {@code null}.
   */
  public Integer getColumnId() {
    return columnId;
  }

  /**
   * Identifier for the column.
   * The value set may be {@code null}.
   */
  public Column setColumnId(Integer columnId) {
    this.columnId = columnId;
    return this;
  }

  /**
   * Type name: a template for an individual column.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Type name: a template for an individual column.
   * The value set may be {@code null}.
   */
  public Column setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Required name of the column.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * Required name of the column.
   * The value set may be {@code null}.
   */
  public Column setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * Required type of the column.
   * The value returned may be {@code null}.
   */
  public String getType() {
    return type;
  }

  /**
   * Required type of the column.
   * The value set may be {@code null}.
   */
  public Column setType(String type) {
    this.type = type;
    return this;
  }

  /**
   * Optional identifier of the base column. If present, this column is derived from the specified
   * base column.
   */
  public static final class BaseColumn extends GenericJson {

    /**
     * The id of the column in the base table from which this column is derived.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer columnId;

    /**
     * Offset to the entry in the list of base tables in the table definition.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer tableIndex;

    /**
     * The id of the column in the base table from which this column is derived.
     * The value returned may be {@code null}.
     */
    public Integer getColumnId() {
      return columnId;
    }

    /**
     * The id of the column in the base table from which this column is derived.
     * The value set may be {@code null}.
     */
    public BaseColumn setColumnId(Integer columnId) {
      this.columnId = columnId;
      return this;
    }

    /**
     * Offset to the entry in the list of base tables in the table definition.
     * The value returned may be {@code null}.
     */
    public Integer getTableIndex() {
      return tableIndex;
    }

    /**
     * Offset to the entry in the list of base tables in the table definition.
     * The value set may be {@code null}.
     */
    public BaseColumn setTableIndex(Integer tableIndex) {
      this.tableIndex = tableIndex;
      return this;
    }

  }

}
