/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.fusiontables.model;

import com.google.api.client.json.GenericJson;

/**
 * Represents a PolygonStyle within a StyleSetting
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Fusion Tables API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class PolygonStyle extends GenericJson {

  /**
   * Color of the interior of the polygon in #RRGGBB format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String fillColor;

  /**
   * Column-value, gradient, or bucket styler that is used to determine the interior color and
   * opacity of the polygon.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private StyleFunction fillColorStyler;

  /**
   * Opacity of the interior of the polygon: 0.0 (transparent) to 1.0 (opaque).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double fillOpacity;

  /**
   * Color of the polygon border in #RRGGBB format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String strokeColor;

  /**
   * Column-value, gradient or buckets styler that is used to determine the border color and
   * opacity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private StyleFunction strokeColorStyler;

  /**
   * Opacity of the polygon border: 0.0 (transparent) to 1.0 (opaque).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double strokeOpacity;

  /**
   * Width of the polyon border in pixels.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer strokeWeight;

  /**
   * Column-value or bucket styler that is used to determine the width of the polygon border.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private StyleFunction strokeWeightStyler;

  /**
   * Color of the interior of the polygon in #RRGGBB format.
   * The value returned may be {@code null}.
   */
  public String getFillColor() {
    return fillColor;
  }

  /**
   * Color of the interior of the polygon in #RRGGBB format.
   * The value set may be {@code null}.
   */
  public PolygonStyle setFillColor(String fillColor) {
    this.fillColor = fillColor;
    return this;
  }

  /**
   * Column-value, gradient, or bucket styler that is used to determine the interior color and
   * opacity of the polygon.
   * The value returned may be {@code null}.
   */
  public StyleFunction getFillColorStyler() {
    return fillColorStyler;
  }

  /**
   * Column-value, gradient, or bucket styler that is used to determine the interior color and
   * opacity of the polygon.
   * The value set may be {@code null}.
   */
  public PolygonStyle setFillColorStyler(StyleFunction fillColorStyler) {
    this.fillColorStyler = fillColorStyler;
    return this;
  }

  /**
   * Opacity of the interior of the polygon: 0.0 (transparent) to 1.0 (opaque).
   * The value returned may be {@code null}.
   */
  public Double getFillOpacity() {
    return fillOpacity;
  }

  /**
   * Opacity of the interior of the polygon: 0.0 (transparent) to 1.0 (opaque).
   * The value set may be {@code null}.
   */
  public PolygonStyle setFillOpacity(Double fillOpacity) {
    this.fillOpacity = fillOpacity;
    return this;
  }

  /**
   * Color of the polygon border in #RRGGBB format.
   * The value returned may be {@code null}.
   */
  public String getStrokeColor() {
    return strokeColor;
  }

  /**
   * Color of the polygon border in #RRGGBB format.
   * The value set may be {@code null}.
   */
  public PolygonStyle setStrokeColor(String strokeColor) {
    this.strokeColor = strokeColor;
    return this;
  }

  /**
   * Column-value, gradient or buckets styler that is used to determine the border color and
   * opacity.
   * The value returned may be {@code null}.
   */
  public StyleFunction getStrokeColorStyler() {
    return strokeColorStyler;
  }

  /**
   * Column-value, gradient or buckets styler that is used to determine the border color and
   * opacity.
   * The value set may be {@code null}.
   */
  public PolygonStyle setStrokeColorStyler(StyleFunction strokeColorStyler) {
    this.strokeColorStyler = strokeColorStyler;
    return this;
  }

  /**
   * Opacity of the polygon border: 0.0 (transparent) to 1.0 (opaque).
   * The value returned may be {@code null}.
   */
  public Double getStrokeOpacity() {
    return strokeOpacity;
  }

  /**
   * Opacity of the polygon border: 0.0 (transparent) to 1.0 (opaque).
   * The value set may be {@code null}.
   */
  public PolygonStyle setStrokeOpacity(Double strokeOpacity) {
    this.strokeOpacity = strokeOpacity;
    return this;
  }

  /**
   * Width of the polyon border in pixels.
   * The value returned may be {@code null}.
   */
  public Integer getStrokeWeight() {
    return strokeWeight;
  }

  /**
   * Width of the polyon border in pixels.
   * The value set may be {@code null}.
   */
  public PolygonStyle setStrokeWeight(Integer strokeWeight) {
    this.strokeWeight = strokeWeight;
    return this;
  }

  /**
   * Column-value or bucket styler that is used to determine the width of the polygon border.
   * The value returned may be {@code null}.
   */
  public StyleFunction getStrokeWeightStyler() {
    return strokeWeightStyler;
  }

  /**
   * Column-value or bucket styler that is used to determine the width of the polygon border.
   * The value set may be {@code null}.
   */
  public PolygonStyle setStrokeWeightStyler(StyleFunction strokeWeightStyler) {
    this.strokeWeightStyler = strokeWeightStyler;
    return this;
  }

}
