/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.fusiontables.model;

import com.google.api.client.json.GenericJson;

/**
 * Represents a StyleFunction within a StyleSetting
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Fusion Tables API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class StyleFunction extends GenericJson {

  /**
   * Bucket function that assigns a style based on the range a column value falls into.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Bucket> buckets;

  static {
    // hack to force ProGuard to consider Bucket used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Bucket.class);
  }

  /**
   * Name of the column whose value is used in the style.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String columnName;

  /**
   * Gradient function that interpolates a range of colors based on column value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Gradient gradient;

  /**
   * Stylers can be one of three kinds: "fusiontables#fromColumn" if the column value is to be used
   * as is, i.e., the column values can have colors in #RRGGBBAA format or integer line widths or
   * icon names; "fusiontables#gradient" if the styling of the row is to be based on applying the
   * gradient function on the column value; or "fusiontables#buckets" if the styling is to based on
   * the bucket into which the the column value falls.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Bucket function that assigns a style based on the range a column value falls into.
   * The value returned may be {@code null}.
   */
  public java.util.List<Bucket> getBuckets() {
    return buckets;
  }

  /**
   * Bucket function that assigns a style based on the range a column value falls into.
   * The value set may be {@code null}.
   */
  public StyleFunction setBuckets(java.util.List<Bucket> buckets) {
    this.buckets = buckets;
    return this;
  }

  /**
   * Name of the column whose value is used in the style.
   * The value returned may be {@code null}.
   */
  public String getColumnName() {
    return columnName;
  }

  /**
   * Name of the column whose value is used in the style.
   * The value set may be {@code null}.
   */
  public StyleFunction setColumnName(String columnName) {
    this.columnName = columnName;
    return this;
  }

  /**
   * Gradient function that interpolates a range of colors based on column value.
   * The value returned may be {@code null}.
   */
  public Gradient getGradient() {
    return gradient;
  }

  /**
   * Gradient function that interpolates a range of colors based on column value.
   * The value set may be {@code null}.
   */
  public StyleFunction setGradient(Gradient gradient) {
    this.gradient = gradient;
    return this;
  }

  /**
   * Stylers can be one of three kinds: "fusiontables#fromColumn" if the column value is to be used
   * as is, i.e., the column values can have colors in #RRGGBBAA format or integer line widths or
   * icon names; "fusiontables#gradient" if the styling of the row is to be based on applying the
   * gradient function on the column value; or "fusiontables#buckets" if the styling is to based on
   * the bucket into which the the column value falls.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Stylers can be one of three kinds: "fusiontables#fromColumn" if the column value is to be used
   * as is, i.e., the column values can have colors in #RRGGBBAA format or integer line widths or
   * icon names; "fusiontables#gradient" if the styling of the row is to be based on applying the
   * gradient function on the column value; or "fusiontables#buckets" if the styling is to based on
   * the bucket into which the the column value falls.
   * The value set may be {@code null}.
   */
  public StyleFunction setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Gradient function that interpolates a range of colors based on column value.
   */
  public static final class Gradient extends GenericJson {

    /**
     * Array with two or more colors.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<Colors> colors;

    static {
      // hack to force ProGuard to consider Colors used, since otherwise it would be stripped out
      // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
      com.google.api.client.util.Data.nullOf(Colors.class);
    }

    /**
     * Higher-end of the interpolation range: rows with this value will be assigned to colors[n-1].
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Double max;

    /**
     * Lower-end of the interpolation range: rows with this value will be assigned to colors[0].
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Double min;

    /**
     * Array with two or more colors.
     * The value returned may be {@code null}.
     */
    public java.util.List<Colors> getColors() {
      return colors;
    }

    /**
     * Array with two or more colors.
     * The value set may be {@code null}.
     */
    public Gradient setColors(java.util.List<Colors> colors) {
      this.colors = colors;
      return this;
    }

    /**
     * Higher-end of the interpolation range: rows with this value will be assigned to colors[n-1].
     * The value returned may be {@code null}.
     */
    public Double getMax() {
      return max;
    }

    /**
     * Higher-end of the interpolation range: rows with this value will be assigned to colors[n-1].
     * The value set may be {@code null}.
     */
    public Gradient setMax(Double max) {
      this.max = max;
      return this;
    }

    /**
     * Lower-end of the interpolation range: rows with this value will be assigned to colors[0].
     * The value returned may be {@code null}.
     */
    public Double getMin() {
      return min;
    }

    /**
     * Lower-end of the interpolation range: rows with this value will be assigned to colors[0].
     * The value set may be {@code null}.
     */
    public Gradient setMin(Double min) {
      this.min = min;
      return this;
    }

    /**
     * Model definition for StyleFunctionGradientColors.
     */
    public static final class Colors extends GenericJson {

      /**
       * Color in #RRGGBB format.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String color;

      /**
       * Opacity of the color: 0.0 (transparent) to 1.0 (opaque).
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Double opacity;

      /**
       * Color in #RRGGBB format.
       * The value returned may be {@code null}.
       */
      public String getColor() {
        return color;
      }

      /**
       * Color in #RRGGBB format.
       * The value set may be {@code null}.
       */
      public Colors setColor(String color) {
        this.color = color;
        return this;
      }

      /**
       * Opacity of the color: 0.0 (transparent) to 1.0 (opaque).
       * The value returned may be {@code null}.
       */
      public Double getOpacity() {
        return opacity;
      }

      /**
       * Opacity of the color: 0.0 (transparent) to 1.0 (opaque).
       * The value set may be {@code null}.
       */
      public Colors setOpacity(Double opacity) {
        this.opacity = opacity;
        return this;
      }

    }
  }

}
