/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.fusiontables.model;

import com.google.api.client.json.GenericJson;

/**
 * Represents a complete StyleSettings object. The primary key is a combination of the tableId and a
 * styleId.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Fusion Tables API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class StyleSetting extends GenericJson {

  /**
   * Type name: an individual style setting. A StyleSetting contains the style defintions for
   * points, lines, and polygons in a table. Since a table can have any one or all of them, a style
   * definition can have point, line and polygon style definitions.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Style definition for points in the table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PointStyle markerOptions;

  /**
   * Optional name for the style setting.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * Style definition for polygons in the table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PolygonStyle polygonOptions;

  /**
   * Style definition for lines in the table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LineStyle polylineOptions;

  /**
   * Identifier for the style setting (unique only within tables).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer styleId;

  /**
   * Identifier for the table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String tableId;

  /**
   * Type name: an individual style setting. A StyleSetting contains the style defintions for
   * points, lines, and polygons in a table. Since a table can have any one or all of them, a style
   * definition can have point, line and polygon style definitions.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Type name: an individual style setting. A StyleSetting contains the style defintions for
   * points, lines, and polygons in a table. Since a table can have any one or all of them, a style
   * definition can have point, line and polygon style definitions.
   * The value set may be {@code null}.
   */
  public StyleSetting setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Style definition for points in the table.
   * The value returned may be {@code null}.
   */
  public PointStyle getMarkerOptions() {
    return markerOptions;
  }

  /**
   * Style definition for points in the table.
   * The value set may be {@code null}.
   */
  public StyleSetting setMarkerOptions(PointStyle markerOptions) {
    this.markerOptions = markerOptions;
    return this;
  }

  /**
   * Optional name for the style setting.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * Optional name for the style setting.
   * The value set may be {@code null}.
   */
  public StyleSetting setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * Style definition for polygons in the table.
   * The value returned may be {@code null}.
   */
  public PolygonStyle getPolygonOptions() {
    return polygonOptions;
  }

  /**
   * Style definition for polygons in the table.
   * The value set may be {@code null}.
   */
  public StyleSetting setPolygonOptions(PolygonStyle polygonOptions) {
    this.polygonOptions = polygonOptions;
    return this;
  }

  /**
   * Style definition for lines in the table.
   * The value returned may be {@code null}.
   */
  public LineStyle getPolylineOptions() {
    return polylineOptions;
  }

  /**
   * Style definition for lines in the table.
   * The value set may be {@code null}.
   */
  public StyleSetting setPolylineOptions(LineStyle polylineOptions) {
    this.polylineOptions = polylineOptions;
    return this;
  }

  /**
   * Identifier for the style setting (unique only within tables).
   * The value returned may be {@code null}.
   */
  public Integer getStyleId() {
    return styleId;
  }

  /**
   * Identifier for the style setting (unique only within tables).
   * The value set may be {@code null}.
   */
  public StyleSetting setStyleId(Integer styleId) {
    this.styleId = styleId;
    return this;
  }

  /**
   * Identifier for the table.
   * The value returned may be {@code null}.
   */
  public String getTableId() {
    return tableId;
  }

  /**
   * Identifier for the table.
   * The value set may be {@code null}.
   */
  public StyleSetting setTableId(String tableId) {
    this.tableId = tableId;
    return this;
  }

}
