/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.fusiontables.model;

import com.google.api.client.json.GenericJson;

/**
 * Represents a table. Specifies the name, whether it is exportable, description, attribution, and
 * attribution link.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Fusion Tables API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Table extends GenericJson {

  /**
   * Optional attribution assigned to the table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String attribution;

  /**
   * Optional link for attribution.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String attributionLink;

  /**
   * Optional base table identifier if this table is a view or merged table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> baseTableIds;

  /**
   * Columns in the table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Column> columns;

  static {
    // hack to force ProGuard to consider Column used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Column.class);
  }

  /**
   * Optional description assigned to the table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * Variable for whether table is exportable.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isExportable;

  /**
   * Type name: a template for an individual table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Name assigned to a table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * Optional sql that encodes the table definition for derived tables.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String sql;

  /**
   * Encrypted unique alphanumeric identifier for the table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String tableId;

  /**
   * Optional attribution assigned to the table.
   * The value returned may be {@code null}.
   */
  public String getAttribution() {
    return attribution;
  }

  /**
   * Optional attribution assigned to the table.
   * The value set may be {@code null}.
   */
  public Table setAttribution(String attribution) {
    this.attribution = attribution;
    return this;
  }

  /**
   * Optional link for attribution.
   * The value returned may be {@code null}.
   */
  public String getAttributionLink() {
    return attributionLink;
  }

  /**
   * Optional link for attribution.
   * The value set may be {@code null}.
   */
  public Table setAttributionLink(String attributionLink) {
    this.attributionLink = attributionLink;
    return this;
  }

  /**
   * Optional base table identifier if this table is a view or merged table.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getBaseTableIds() {
    return baseTableIds;
  }

  /**
   * Optional base table identifier if this table is a view or merged table.
   * The value set may be {@code null}.
   */
  public Table setBaseTableIds(java.util.List<String> baseTableIds) {
    this.baseTableIds = baseTableIds;
    return this;
  }

  /**
   * Columns in the table.
   * The value returned may be {@code null}.
   */
  public java.util.List<Column> getColumns() {
    return columns;
  }

  /**
   * Columns in the table.
   * The value set may be {@code null}.
   */
  public Table setColumns(java.util.List<Column> columns) {
    this.columns = columns;
    return this;
  }

  /**
   * Optional description assigned to the table.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * Optional description assigned to the table.
   * The value set may be {@code null}.
   */
  public Table setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * Variable for whether table is exportable.
   * The value returned may be {@code null}.
   */
  public Boolean getIsExportable() {
    return isExportable;
  }

  /**
   * Variable for whether table is exportable.
   * The value set may be {@code null}.
   */
  public Table setIsExportable(Boolean isExportable) {
    this.isExportable = isExportable;
    return this;
  }

  /**
   * Type name: a template for an individual table.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Type name: a template for an individual table.
   * The value set may be {@code null}.
   */
  public Table setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Name assigned to a table.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * Name assigned to a table.
   * The value set may be {@code null}.
   */
  public Table setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * Optional sql that encodes the table definition for derived tables.
   * The value returned may be {@code null}.
   */
  public String getSql() {
    return sql;
  }

  /**
   * Optional sql that encodes the table definition for derived tables.
   * The value set may be {@code null}.
   */
  public Table setSql(String sql) {
    this.sql = sql;
    return this;
  }

  /**
   * Encrypted unique alphanumeric identifier for the table.
   * The value returned may be {@code null}.
   */
  public String getTableId() {
    return tableId;
  }

  /**
   * Encrypted unique alphanumeric identifier for the table.
   * The value set may be {@code null}.
   */
  public Table setTableId(String tableId) {
    this.tableId = tableId;
    return this;
  }

}
