/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.fusiontables.model;

import com.google.api.client.json.GenericJson;

/**
 * Represents the contents of InfoWindow templates.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Fusion Tables API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Template extends GenericJson {

  /**
   * List of columns from which the template is to be automatically constructed. Only one of body or
   * automaticColumns can be specified.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> automaticColumnNames;

  /**
   * Body of the template. It contains HTML with {column_name} to insert values from a particular
   * column. The body is sanitized to remove certain tags, e.g., script. Only one of body or
   * automaticColumns can be specified.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String body;

  /**
   * Type name: a template for the info window contents. The template can either include an HTML
   * body or a list of columns from which the template is computed automatically.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Optional name assigned to a template.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * Identifier for the table for which the template is defined.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String tableId;

  /**
   * Identifier for the template, unique within the context of a particular table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer templateId;

  /**
   * List of columns from which the template is to be automatically constructed. Only one of body or
   * automaticColumns can be specified.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getAutomaticColumnNames() {
    return automaticColumnNames;
  }

  /**
   * List of columns from which the template is to be automatically constructed. Only one of body or
   * automaticColumns can be specified.
   * The value set may be {@code null}.
   */
  public Template setAutomaticColumnNames(java.util.List<String> automaticColumnNames) {
    this.automaticColumnNames = automaticColumnNames;
    return this;
  }

  /**
   * Body of the template. It contains HTML with {column_name} to insert values from a particular
   * column. The body is sanitized to remove certain tags, e.g., script. Only one of body or
   * automaticColumns can be specified.
   * The value returned may be {@code null}.
   */
  public String getBody() {
    return body;
  }

  /**
   * Body of the template. It contains HTML with {column_name} to insert values from a particular
   * column. The body is sanitized to remove certain tags, e.g., script. Only one of body or
   * automaticColumns can be specified.
   * The value set may be {@code null}.
   */
  public Template setBody(String body) {
    this.body = body;
    return this;
  }

  /**
   * Type name: a template for the info window contents. The template can either include an HTML
   * body or a list of columns from which the template is computed automatically.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Type name: a template for the info window contents. The template can either include an HTML
   * body or a list of columns from which the template is computed automatically.
   * The value set may be {@code null}.
   */
  public Template setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Optional name assigned to a template.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * Optional name assigned to a template.
   * The value set may be {@code null}.
   */
  public Template setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * Identifier for the table for which the template is defined.
   * The value returned may be {@code null}.
   */
  public String getTableId() {
    return tableId;
  }

  /**
   * Identifier for the table for which the template is defined.
   * The value set may be {@code null}.
   */
  public Template setTableId(String tableId) {
    this.tableId = tableId;
    return this;
  }

  /**
   * Identifier for the template, unique within the context of a particular table.
   * The value returned may be {@code null}.
   */
  public Integer getTemplateId() {
    return templateId;
  }

  /**
   * Identifier for the template, unique within the context of a particular table.
   * The value set may be {@code null}.
   */
  public Template setTemplateId(Integer templateId) {
    this.templateId = templateId;
    return this;
  }

}
